# Harness-Bench Comparison Report

**Date:** 2026-02-22T14:36:46
**Tasks:** 8

## Overall Results

| Agent | gpt52 |
|-------|------|
| **harness** | 2/8 (25%) |

## Per-Task Results

### Model: gpt52

| Task | harness |
|------|------|
| hb-multi-file-01 | FAIL (1.7s) |
| hb-recovery-01 | FAIL (1.1s) |
| hb-tool-efficiency-01 | PASS (0.6s) |
| hb-context-01 | FAIL (2.7s) |
| hb-create-01 | FAIL (1.4s) |
| hb-bugfix-01 | FAIL (1.0s) |
| hb-analyze-01 | PASS (0.5s) |
| hb-refactor-01 | FAIL (1.9s) |

## Timing

| Agent | Model | Avg Duration | Total Duration |
|-------|-------|-------------|----------------|
| harness | gpt52 | 1.4s | 10.9s |
